@@ -1,4 +1,5 @@
 use crate::context::GeneratorContext;
+use crate::deserialize::{deserialize_tags, utc_date};
 use chrono::{Date, Utc};
 use log::warn;
 use pulldown_cmark::{html, CowStr, Event, LinkType, Options, Parser, Tag};
@@ -29,16 +30,18 @@ pub fn read_markdown_file(path: PathBuf) -> Option<MarkdownFile> {
     });
 }
 
-#[derive(Debug, Deserialize)]
+#[derive(Debug, Deserialize, Clone)]
 pub struct Frontmatter {
     pub title: Option<String>,
 
     #[serde(with = "utc_date", default)]
     pub date: Option<Date<Utc>>,
+    #[serde(deserialize_with = "deserialize_tags")]
     pub tags: Vec<String>,
+    pub author: Option<String>,
 }
 
-#[derive(Debug)]
+#[derive(Debug, Clone)]
 pub struct MarkdownFile {
     pub path: PathBuf,
     pub frontmatter: Frontmatter,
@@ -253,20 +256,3 @@ fn rewrite_relative_url<'a>(
 
     Event::Start(Tag::Link(link_type, target, title))
 }
-
-mod utc_date {
-    use chrono::{Date, NaiveDate, Utc};
-    use serde::{Deserialize, Deserializer};
-
-    pub fn deserialize<'de, D>(deserializer: D) -> Result<Option<Date<Utc>>, D::Error>
-    where
-        D: Deserializer<'de>,
-    {
-        let s = String::deserialize(deserializer)?;
-        let parsed = s.parse::<NaiveDate>().map(|s| Date::from_utc(s, Utc));
-        match parsed {
-            Ok(p) => Ok(Some(p)),
-            Err(_) => Ok(None),
-        }
-    }
-}
